@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.alloc.c,v 3.33 1998/10/25 15:10:28 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.alloc.c,v 3.34 1999/04/20 07:48:49 christos Exp $ */
 /*
  * tc.alloc.c (Caltech) 2/21/82
  * Chris Kingsley, kingsley@cit-20.
@@ -44,13 +44,17 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.alloc.c,v 3.33 1998/10/25 15:10:28 christos Exp $")
+RCSID("$Id: tc.alloc.c,v 3.34 1999/04/20 07:48:49 christos Exp $")
 
 static char   *memtop = NULL;		/* PWP: top of current memory */
 static char   *membot = NULL;		/* PWP: bottom of allocatable memory */
 
 int dont_free = 0;
 
+#if defined(_VMS_POSIX) || defined(_AMIGA_MEMORY)
+# define NO_SBRK
+#endif
+
 #ifdef WINNT
 # define malloc		fmalloc
 # define free		ffree
@@ -493,21 +497,21 @@ smalloc(n)
 
     n = n ? n : 1;
 
-#ifndef _VMS_POSIX
+#ifndef NO_SBRK
     if (membot == NULL)
 	membot = (char*) sbrk(0);
-#endif /* !_VMS_POSIX */
+#endif /* !NO_SBRK */
 
     if ((ptr = malloc(n)) == (ptr_t) 0) {
 	child++;
 	stderror(ERR_NOMEM);
     }
-#ifdef _VMS_POSIX
+#ifdef NO_SBRK
     if (memtop < ((char *) ptr) + n)
 	memtop = ((char *) ptr) + n;
     if (membot == NULL)
 	membot = (char*) ptr;
-#endif /* _VMS_POSIX */
+#endif /* NO_SBRK */
     return ((memalign_t) ptr);
 }
 
@@ -520,21 +524,21 @@ srealloc(p, n)
 
     n = n ? n : 1;
 
-#ifndef _VMS_POSIX
+#ifndef NO_SBRK
     if (membot == NULL)
 	membot = (char*) sbrk(0);
-#endif /* _VMS_POSIX */
+#endif /* NO_SBRK */
 
     if ((ptr = (p ? realloc(p, n) : malloc(n))) == (ptr_t) 0) {
 	child++;
 	stderror(ERR_NOMEM);
     }
-#ifdef _VMS_POSIX
+#ifdef NO_SBRK
     if (memtop < ((char *) ptr) + n)
 	memtop = ((char *) ptr) + n;
     if (membot == NULL)
 	membot = (char*) ptr;
-#endif /* _VMS_POSIX */
+#endif /* NO_SBRK */
     return ((memalign_t) ptr);
 }
 
@@ -548,10 +552,10 @@ scalloc(s, n)
     n *= s;
     n = n ? n : 1;
 
-#ifndef _VMS_POSIX
+#ifndef NO_SBRK
     if (membot == NULL)
 	membot = (char*) sbrk(0);
-#endif /* _VMS_POSIX */
+#endif /* NO_SBRK */
 
     if ((ptr = malloc(n)) == (ptr_t) 0) {
 	child++;
@@ -564,12 +568,12 @@ scalloc(s, n)
 	    *sptr++ = 0;
 	while (--n);
 
-#ifdef _VMS_POSIX
+#ifdef NO_SBRK
     if (memtop < ((char *) ptr) + n)
 	memtop = ((char *) ptr) + n;
     if (membot == NULL)
 	membot = (char*) ptr;
-#endif /* _VMS_POSIX */
+#endif /* NO_SBRK */
 
     return ((memalign_t) ptr);
 }
@@ -621,9 +625,9 @@ showall(v, c)
 	    (unsigned long) membot, (unsigned long) memtop,
 	    (unsigned long) sbrk(0));
 #else
-#ifndef _VMS_POSIX
+#ifndef NO_SBRK
     memtop = (char *) sbrk(0);
-#endif /* !_VMS_POSIX */
+#endif /* !NO_SBRK */
     xprintf(CGETS(19, 12, "Allocated memory from 0x%lx to 0x%lx (%ld).\n"),
 	    (unsigned long) membot, (unsigned long) memtop, 
 	    (unsigned long) (memtop - membot));
