@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.os.h,v 3.80 1998/10/25 15:10:36 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.os.h,v 3.82 1999/02/06 15:19:03 christos Exp $ */
 /*
  * tc.os.h: Shell os dependent defines
  */
@@ -692,8 +692,10 @@ extern int readlink __P((const char *, char *, size_t));
 extern void setgrent __P((void));
 extern void endgrent __P((void));
 # ifdef REMOTEHOST
+#  ifndef _SOCKLEN_T	/* Avoid Solaris 2.7 bogosity. */
 struct sockaddr;
 extern int getpeername __P((int, struct sockaddr *, int *));
+#  endif /* _SOCKLEN_T */
 # endif /* REMOTEHOST */
 #endif /* SUNOS4 && __GNUC__ == 2 */
 
@@ -721,9 +723,11 @@ extern void bcopy	__P((const void *, void *, size_t));
 /* Irix6 defines getpeername(int, void *, int *) which conflicts with
    the definition below. */
 #  if !defined(__sgi) && !defined(_OSD_POSIX)
+#   ifndef _SOCKLEN_T	/* Avoid Solaris 2.7 bogosity. */
 struct sockaddr;
 extern int getpeername __P((int, struct sockaddr *, int *));
-#  endif /* __sgi */
+#   endif /* _SOCKLEN_T */
+#  endif /* !__sgi && !_OSD_POSIX */
 # endif /* REMOTEHOST */
 # ifndef BSDTIMES
 extern int getrlimit __P((int, struct rlimit *));
